-- This SQL removes duplicate settings from the xepm_settings table.
-- A duplicate setting is a setting with the same parent_id and name (case sensitive).
-- This SQL is safe to run multiple times.
use `ombutel`;

-- First, create a temporary table for the settings we want to keep
CREATE TEMPORARY TABLE `ombutel`.`settings_to_keep` (
    `parent_id` int(11),
    `name` varchar(255),
    `max_setting_id` int(11),
    KEY `idx_parent_name` (`parent_id`, `name`)
);

-- Populate it with the latest setting_id for each parent_id + name combination that has duplicates
INSERT INTO `ombutel`.`settings_to_keep`
SELECT `parent_id`, `name`, MAX(`setting_id`) AS `max_setting_id`
FROM `ombutel`.`xepm_settings`
GROUP BY `parent_id`, `name`
HAVING COUNT(*) > 1;

-- Now delete all duplicates except the ones we want to keep
DELETE s FROM `ombutel`.`xepm_settings` s
INNER JOIN `ombutel`.`settings_to_keep` k
    ON k.`parent_id` = s.`parent_id`
    AND k.`name` = s.`name`
    AND k.`max_setting_id` != s.`setting_id`;

-- Clean up
DROP TABLE `ombutel`.`settings_to_keep`;
