(function () {
	var tg_form = Ombutel.find('#time_group_form');
	var tg_interval = 100;

	// Add styling for disabled remove buttons
	$("<style>")
		.text(".remove-basic-time-slot.disabled { opacity: 0.5; cursor: not-allowed; }")
		.appendTo("head");

	// Initialize autocomplete for description field in add mode
	if(tg_form.find("#mode").val() == "add") {
		tg_form.find("[name='description']").autocomplete({
			source: timeGroupAutoComplete,
			select: function(event, ui) {
				pbx_request("time_group", "getContent", "edit", ui.item.id);
			}
		});
	}

	register_timer("time_group", "init_jui_time", init_jui_time, tg_interval, true);

	function init_jui_time(){
		tg_form.validate(Validations);

		tg_form.find('.row-to-add-jui-time').each(function(i, e){
			var o = $(this);
			if(!o.hasClass('repeat-template')){
				var tstart = o.find('.time-start');
				var tend = o.find('.time-end');

				tstart.timepicker();
				tend.timepicker();

				o.removeClass('row-to-add-jui-time');
			}
		});

		// Initialize time pickers for basic time group
		tg_form.find('.time-picker').timepicker({
			timeFormat: 'HH:mm'
		});

		// Initialize datetime pickers for exception days
		initExceptionDatetimePickers();
	}

	// Function to initialize datetime pickers for exception days
	function initExceptionDatetimePickers() {
		tg_form.find('.exception-date-time').each(function() {
			// Skip template rows (they contain placeholder values)
			if ($(this).closest('.repeat-template').length > 0 || $(this).attr('name').indexOf('{{row-count-placeholder}}') !== -1) {
				return;
			}

			// Destroy any existing picker to prevent duplicates
			if ($(this).data('DateTimePicker')) {
				$(this).data('DateTimePicker').destroy();
			}
			// Initialize the picker
			$(this).datetimepicker({
				format: 'YYYY-MM-DD HH:mm',
				stepping: 15
			});
		});
	}

	// Function to toggle advanced type elements
	function toggleAdvancedType() {
		var selectedType = $("input[name='type']:checked").val();
		if (selectedType === "advanced") {
			$(".advanced-type-group").show();
			$(".basic-type-group").hide();
		} else {
			$(".advanced-type-group").hide();
			$(".basic-type-group").show();
		}
	}

	// Initial toggle based on current selection
	toggleAdvancedType();

	// Toggle when type selection changes
	$("input[name='type']").change(function() {
		toggleAdvancedType();
	});

	// For edit mode, check the hidden input value
	if ($("input[name='type']").attr("type") === "hidden") {
		var hiddenType = $("input[name='type']").val();
		if (hiddenType === "advanced") {
			$(".advanced-type-group").show();
			$(".basic-type-group").hide();
		} else {
			$(".advanced-type-group").hide();
			$(".basic-type-group").show();
		}
	}

	// Initialize additional time slots if they exist
	function initializeAdditionalTimeSlots(day) {
		// Loop through each day
		$('.basic-day-row').each(function() {
			var dayId = $(this).attr('id').replace('day-', '');
			if(dayId === day) {

				var additionalSlotsContainer = $('#additional-slots-' + dayId);
				var additionalSlotsWrapper = additionalSlotsContainer.find('.additional-slots-wrapper');

				// Clear out any existing slots that might be there
				additionalSlotsWrapper.empty();

				// First, collect all hidden inputs for this day's slots
				var hiddenInputs = {};

				// Look for hidden inputs in the hidden-additional-slots-inputs container
				$('#hidden-additional-slots-inputs input[type="hidden"]').each(function() {
					var name = $(this).attr('name');
					var value = $(this).val();

					// Check if this input is for the current day
					if (name.indexOf('basic_days[' + dayId + '][slots]') === -1) {
						return; // Skip inputs for other days
					}

					// Extract the slot ID and field (start/end)
					var match = name.match(/basic_days\[.*?\]\[slots\]\[(\d+)\]\[(start|end)\]/);
					if (match) {
						var slotId = match[1];
						var field = match[2];

						// Skip slot 0 as it's the main slot
						if (slotId === '0') {
							return;
						}

						if (!hiddenInputs[slotId]) {
							hiddenInputs[slotId] = {};
						}

						hiddenInputs[slotId][field] = value;
					}
				});


				// Convert to array and sort by slot ID
				var slotIds = Object.keys(hiddenInputs).sort(function(a, b) {
					return parseInt(a) - parseInt(b);
				});

				// If we have additional slots, show them
				if (slotIds.length > 0) {
					// For each additional slot, create the UI
					for (var i = 0; i < slotIds.length; i++) {
						var slotId = slotIds[i];
						var slotData = hiddenInputs[slotId];

						var startValue = slotData.start || '';
						var endValue = slotData.end || '';

						// Only create the slot if we have values
						if (startValue && endValue) {
							// Create a new time slot row
							var newSlot = $('<div class="additional-slot" data-slot-id="' + slotId + '"></div>');

							// Create a table-like layout for the additional slot
							var slotTable = $('<table class="additional-slot-table" width="100%"><tr></tr></table>');
							var slotRow = slotTable.find('tr');

							// Empty first column (for alignment with checkbox)
							slotRow.append('<td width="5%"></td>');

							// Empty column for day name (for alignment)
							slotRow.append('<td width="40%"></td>');

							// Start time column
							slotRow.append('<td width="20%" class="center">' +
								'<input type="text" name="basic_days[' + dayId + '][slots][' + slotId + '][start]" ' +
								'class="form-control time-picker start-time" value="' + startValue + '" placeholder="--:--">' +
								'</td>');

							// End time column
							slotRow.append('<td width="20%" class="center">' +
								'<input type="text" name="basic_days[' + dayId + '][slots][' + slotId + '][end]" ' +
								'class="form-control time-picker end-time" value="' + endValue + '" placeholder="--:--">' +
								'</td>');

							// Remove button column
							slotRow.append('<td width="15%" class="center">' +
								'<button type="button" class="btn btn-xs btn-danger remove-basic-time-slot" data-slot-id="' + slotId + '">' +
								'<i class="fa fa-trash"></i></button>' +
								'</td>');

							// Append the table to the slot and the slot to the container
							newSlot.append(slotTable);
							additionalSlotsWrapper.append(newSlot);
						}
					}

					// Show the additional slots container if we added any slots
					if (additionalSlotsWrapper.find('.additional-slot').length > 0) {
						additionalSlotsContainer.show();
					}

					// Initialize timepicker for all the time inputs
					additionalSlotsWrapper.find('.time-picker').timepicker({
						timeFormat: 'HH:mm'
					});

					// Apply the enabled/disabled state based on the checkbox
					var isEnabled = $('#day-' + dayId).find('.day-enabled-checkbox').is(':checked');
					additionalSlotsWrapper.find('input, button').prop('disabled', !isEnabled);
				}
			}
		});
	}

	// Initialize timepickers when the document is ready
	$(document).ready(function() {
		$('form').on('submit', function() {

			$('.day-enabled-checkbox').each(function() {
				var checkbox = $(this);
				var dayId = checkbox.closest('.basic-day-row').attr('id').replace('day-', '');
				var isChecked = checkbox.is(':checked');
				var isExplicitlyDisabled = $('input[name="basic_days[' + dayId + '][explicitly_disabled]"]').val() === '1';
				var hiddenInputs = $('.hidden-disabled-day-' + dayId);
			});

			// Let the form submit normally
			return true;
		});

		// Initialize timepickers for the basic day slots
		$('.time-picker').timepicker({
			timeFormat: 'HH:mm'
		});

		// Initialize datetime pickers for exception days
		initExceptionDatetimePickers();

		// Initialize additional time slots immediately
		initializeAdditionalTimeSlots('sunday');
		initializeAdditionalTimeSlots('monday');
		initializeAdditionalTimeSlots('tuesday');
		initializeAdditionalTimeSlots('wednesday');
		initializeAdditionalTimeSlots('thursday');
		initializeAdditionalTimeSlots('friday');
		initializeAdditionalTimeSlots('saturday');

		// Initialize additional slots containers if they have content
		$('.additional-slots-container').each(function() {
			var container = $(this);
			var dayId = container.attr('id').replace('additional-slots-', '');

			// Check if there are additional slots
			if (container.find('.additional-slot').length > 0) {
				container.show();
			} else {
				container.hide();
			}
		});

		// Trigger the change event to set the initial state
		$('.day-enabled-checkbox').each(function() {
			$(this).trigger('change');
		});

		// Toggle gray text for disabled days
		$('.basic-day-checkbox').each(function() {
			updateDayTextStyle($(this));
		});
		
		// Listen for changes
		$(document).on('change', '.basic-day-checkbox', function() {
			updateDayTextStyle($(this));
		});
	});
	
	function updateDayTextStyle(checkbox) {
		var dayLabel = checkbox.closest('tr').find('.day-name');
		if (checkbox.is(':checked')) {
			dayLabel.removeClass('text-muted');
		} else {
			dayLabel.addClass('text-muted');
		}
	}

	// Override the repeatable_fields plugin's after_add method
	var originalAfterAdd = $.fn.repeatable_fields.after_add;
	$.fn.repeatable_fields.after_add = function(container, new_row) {
		// Call the original after_add to handle row numbering, etc.
		if (typeof originalAfterAdd === 'function') {
			originalAfterAdd.call(this, container, new_row);
		}

		// Check if this is an exception dates row by looking for exception-date-time class
		if (new_row.find('.exception-date-time').length > 0) {
			// Initialize datetime pickers in the new row
			new_row.find('.exception-date-time').each(function() {
				$(this).datetimepicker({
					format: 'YYYY-MM-DD HH:mm',
					stepping: 15
				});
			});
		}
	};

	// Listen for click on the "Add" button in the exception dates section
	$(document).on('click', '#exception-dates .repeat-add', function() {
		// Wait a bit after adding a new row to make sure it's fully in the DOM
		setTimeout(function() {
			// Get all rows except template
			var rows = $('#exception-dates').find('.row, .repeat-row').not('.repeat-template');

			// Find the last row (newly added)
			var lastRow = rows.last();

			// Initialize datetime pickers in the last row
			lastRow.find('.exception-date-time').each(function() {
				$(this).datetimepicker({
					format: 'YYYY-MM-DD HH:mm',
					stepping: 15
				});
			});
		}, 200);
	});

	// Add a new time slot for a day
	function addBasicTimeSlot(dayId) {
		// Get the next available slot ID
		var nextSlotId = getNextSlotId(dayId);

		// Get the container for additional slots
		var additionalSlotsContainer = $('#additional-slots-' + dayId);
		var additionalSlotsWrapper = additionalSlotsContainer.find('.additional-slots-wrapper');

		// Create a new time slot row
		var newSlot = $('<div class="additional-slot" data-slot-id="' + nextSlotId + '"></div>');

		// Create a table-like layout for the additional slot
		var slotTable = $('<table class="additional-slot-table" width="100%"><tr></tr></table>');
		var slotRow = slotTable.find('tr');

		// Empty first column (for alignment with checkbox)
		slotRow.append('<td width="5%"></td>');

		// Empty column for day name (for alignment)
		slotRow.append('<td width="40%"></td>');

		// Start time column
		slotRow.append('<td width="20%" class="center">' +
			'<input type="text" name="basic_days[' + dayId + '][slots][' + nextSlotId + '][start]" ' +
			'class="form-control time-picker start-time" placeholder="--:--">' +
			'</td>');

		// End time column
		slotRow.append('<td width="20%" class="center">' +
			'<input type="text" name="basic_days[' + dayId + '][slots][' + nextSlotId + '][end]" ' +
			'class="form-control time-picker end-time" placeholder="--:--">' +
			'</td>');

		// Remove button column
		slotRow.append('<td width="15%" class="center">' +
			'<button type="button" class="btn btn-xs btn-danger remove-basic-time-slot" data-slot-id="' + nextSlotId + '">' +
			'<i class="fa fa-trash"></i></button>' +
			'</td>');

		// Append the table to the slot and the slot to the container
		newSlot.append(slotTable);
		additionalSlotsWrapper.append(newSlot);

		// Show the additional slots container
		additionalSlotsContainer.show();

		// Initialize timepicker for the new inputs
		newSlot.find('.time-picker').timepicker({
			timeFormat: 'HH:mm'
		});

		// Apply the enabled/disabled state based on the checkbox
		var isEnabled = $('#day-' + dayId).find('.day-enabled-checkbox').is(':checked');
		newSlot.find('input, button').prop('disabled', !isEnabled);

		// Focus the start time input
		newSlot.find('.start-time').focus();

		return nextSlotId;
	}

	// Get the next available slot ID for a day
	function getNextSlotId(dayId) {
		// Get all existing slot IDs for this day
		var slotIds = [];

		// Check visible slots in the UI
		$('#additional-slots-' + dayId + ' .additional-slot').each(function() {
			var slotId = parseInt($(this).attr('data-slot-id'));
			slotIds.push(slotId);
		});

		// Also check hidden inputs
		$('input[name^="basic_days[' + dayId + '][slots]"]').each(function() {
			var name = $(this).attr('name');
			var match = name.match(/basic_days\[.*?\]\[slots\]\[(\d+)\]/);
			if (match && match[1] !== '0') {
				slotIds.push(parseInt(match[1]));
			}
		});

		// Find the highest slot ID
		var maxSlotId = 0;
		for (var i = 0; i < slotIds.length; i++) {
			if (slotIds[i] > maxSlotId) {
				maxSlotId = slotIds[i];
			}
		}

		// Return the next available slot ID
		return maxSlotId + 1;
	}

	// Keep track of deleted slots
	var deletedSlots = {};

	// Handle adding new time slots in basic time group
	$(document).off('click', '.add-basic-time-slot').on('click', '.add-basic-time-slot', function() {
		var dayId = $(this).data('day');
		addBasicTimeSlot(dayId);
		return false; // Prevent default action
	});

	// Handle removing time slots in basic time group
	$(document).off('click', '.remove-basic-time-slot').on('click', '.remove-basic-time-slot', function() {
		var slotId = $(this).data('slot-id');
		var dayId = $(this).closest('.additional-slots-container').attr('id').replace('additional-slots-', '');
		var slot = $(this).closest('.additional-slot');
		var additionalSlotsContainer = slot.closest('.additional-slots-container');
		var slotsWrapper = slot.closest('.additional-slots-wrapper');

		// Add to the list of deleted slots
		if (!deletedSlots[dayId]) {
			deletedSlots[dayId] = [];
		}
		deletedSlots[dayId].push(slotId);

		// Create a hidden input to mark this slot as deleted
		$('<input>').attr({
			type: 'hidden',
			name: 'deleted_slots[' + dayId + '][' + slotId + ']',
			value: '1'
		}).appendTo('#hidden-additional-slots-inputs');

		// Remove the slot from the UI
		slot.remove();

		// If there are no more slots, hide the container
		if (slotsWrapper.find('.additional-slot').length === 0) {
			additionalSlotsContainer.hide();
		}

		return false; // Prevent default action
	});

	// Toggle time slot availability when day checkbox changes
	$(document).on('change', '.day-enabled-checkbox', function() {
		var isChecked = $(this).is(':checked');
		var dayRow = $(this).closest('.basic-day-row');
		var dayId = dayRow.attr('id').replace('day-', '');
		var additionalSlotsRow = $('#additional-slots-' + dayId);

		if (isChecked) {
			// When enabled, use regular inputs
			dayRow.find('input, button').not('.day-enabled-checkbox').prop('disabled', false);
			additionalSlotsRow.find('input, button').prop('disabled', false);

			// Remove disabled styling class from buttons
			additionalSlotsRow.find('.remove-basic-time-slot').removeClass('disabled');

			// Remove any hidden inputs for this day
			$('.hidden-disabled-day-' + dayId).remove();

            // Only show the additional slots container if it has slots
            if (additionalSlotsRow.find('.additional-slot').length > 0) {
                additionalSlotsRow.show();
            } else {
                additionalSlotsRow.hide();
            }
		} else {
			// When disabled, create hidden inputs to preserve the values with a disabled flag

			// First, create a hidden input for the enabled status with value 0
			$('<input>').attr({
				type: 'hidden',
				name: 'basic_days[' + dayId + '][enabled]',
				value: '0',
				class: 'hidden-disabled-day-' + dayId
			}).appendTo('#hidden-additional-slots-inputs');

			// Add a special flag to indicate this day is explicitly disabled
			$('<input>').attr({
				type: 'hidden',
				name: 'basic_days[' + dayId + '][explicitly_disabled]',
				value: '1',
				class: 'hidden-disabled-day-' + dayId
			}).appendTo('#hidden-additional-slots-inputs');

			dayRow.find('input[type="text"]').each(function() {
				var input = $(this);
				var name = input.attr('name');
				var value = input.val();

				// Only create hidden input if it has a value
				if (value && value !== '--:--') {
					// Create a hidden input with the same name
					$('<input>').attr({
						type: 'hidden',
						name: name,
						value: value,
						class: 'hidden-disabled-day-' + dayId
					}).appendTo('#hidden-additional-slots-inputs');
				}
			});

			// Do the same for additional slots
			additionalSlotsRow.find('input[type="text"]').each(function() {
				var input = $(this);
				var name = input.attr('name');
				var value = input.val();

				// Only create hidden input if it has a value
				if (value && value !== '--:--') {
					// Create a hidden input with the same name
					$('<input>').attr({
						type: 'hidden',
						name: name,
						value: value,
						class: 'hidden-disabled-day-' + dayId
					}).appendTo('#hidden-additional-slots-inputs');
				}
			});

			// Disable the visual inputs
			dayRow.find('input, button').not('.day-enabled-checkbox').prop('disabled', true);
			additionalSlotsRow.find('input, button').prop('disabled', true);
			additionalSlotsRow.find('.remove-basic-time-slot').addClass('disabled');
		}
	});

	// Ensure any unchecked day checkboxes still have their values preserved on initial load
	// This handles the case where a saved time group has disabled days with time slots
	setTimeout(function() {
		$('.day-enabled-checkbox').each(function() {
			if (!$(this).is(':checked')) {
				var dayRow = $(this).closest('.basic-day-row');
				var dayId = dayRow.attr('id').replace('day-', '');
				var additionalSlotsRow = $('#additional-slots-' + dayId);

				// If there are no hidden inputs for this day yet, create them
				if ($('.hidden-disabled-day-' + dayId).length === 0) {
					// First check if the day has any time values - if not, no need to create hidden inputs
					var hasValues = false;

					// Check main row
					dayRow.find('input[type="text"]').each(function() {
						if ($(this).val() && $(this).val() !== '--:--') {
							hasValues = true;
							return false; // break the each loop
						}
					});

					// Check additional slots
					if (!hasValues) {
						additionalSlotsRow.find('input[type="text"]').each(function() {
							if ($(this).val() && $(this).val() !== '--:--') {
								hasValues = true;
								return false; // break the each loop
							}
						});
					}

					// If values exist, create hidden inputs
					if (hasValues) {
						$(this).trigger('change'); // This will create the hidden inputs
					}
				}
				// Disable the visual inputs
				dayRow.find('input, button').not('.day-enabled-checkbox').prop('disabled', true);
				additionalSlotsRow.find('input, button').prop('disabled', true);
				additionalSlotsRow.find('.remove-basic-time-slot').addClass('disabled');
			}
		});
	}, 500);

	// Auto-complete time fields for advanced scheduler
	$(document).on('change', '.time-start', function () {
		var time_end = $(this).closest('tr').find('.time-end');
		if ($(this).val() && (time_end.val() == '' || time_end.val() == '*')) {
			time_end.val('23:59');
		}
	});
	$(document).on('change', '.time-end', function () {
		var time_start = $(this).closest('tr').find('.time-start');
		if ($(this).val() && (time_start.val() == '' || time_start.val() == '*')) {
			time_start.val('00:01');
		}
	});

	// Auto-complete time fields for basic scheduler
	$(document).on('change', '.basic-type-group .start-time', function() {
		var time_end = $(this).closest('tr, .additional-slot-table').find('.end-time');
		if ($(this).val() && (time_end.val() == '' || time_end.val() == '--:--')) {
			time_end.val('23:59');
		}
	});

	$(document).on('change', '.basic-type-group .end-time', function() {
		var time_start = $(this).closest('tr, .additional-slot-table').find('.start-time');
		if ($(this).val() && (time_start.val() == '' || time_start.val() == '--:--')) {
			time_start.val('00:01');
		}
	});

	$(document).on('change', '.day-start', function () {
		var day_end = $(this).closest('tr').find('.day-end');
		if ($(this).val() && (day_end.val() == '' || day_end.val() == '*')) {
			day_end.val($(this).val());
		}
	});

	$(document).on('change', '.month_day-start', function () {
		var month_day_end = $(this).closest('tr').find('.month_day-end');
		if ($(this).val() && (month_day_end.val() == '' || month_day_end.val() == '*')) {
			month_day_end.val($(this).val());
		}
	});

	$(document).on('change', '.month-start', function () {
		var month_end = $(this).closest('tr').find('.month-end');
		if ($(this).val() && (month_end.val() == '' || month_end.val() == '*')) {
			month_end.val($(this).val());
		}
	});

	$(document).on('change', '.day-end', function () {
		var day_start = $(this).closest('tr').find('.day-start');
		if ($(this).val() && (day_start.val() == '' || day_start.val() == '*')) {
			day_start.val($(this).val());
		}
	});

	$(document).on('change', '.month_day-end', function () {
		var month_day_start = $(this).closest('tr').find('.month_day-start');
		if ($(this).val() && (month_day_start.val() == '' || month_day_start.val() == '*')) {
			month_day_start.val($(this).val());
		}
	});

	$(document).on('change', '.month-end', function () {
		var month_start = $(this).closest('tr').find('.month-start');
		if ($(this).val() && (month_start.val() == '' || month_start.val() == '*')) {
			month_start.val($(this).val());
		}
	});
})();
